@@ -1,10 +1,11 @@
 // file      : xsde/cxx/parser/validating/ncname-stl.cxx
 // author    : Boris Kolpackov <boris@codesynthesis.com>
-// copyright : Copyright (c) 2005-2007 Code Synthesis Tools CC
+// copyright : Copyright (c) 2005-2008 Code Synthesis Tools CC
 // license   : GNU GPL v2 + exceptions; see accompanying LICENSE file
 
+#include <xsde/cxx/xml/ncname.hxx>
+
 #include <xsde/cxx/parser/validating/ncname-stl.hxx>
-#include <xsde/cxx/parser/validating/ncname-common.hxx>
 
 namespace xsde
 {
@@ -40,10 +41,10 @@ namespace xsde
           ro_string tmp (str_);
           ro_string::size_type size = trim_right (tmp);
 
-          if (bits::valid_ncname (tmp.data (), size))
+          if (xml::valid_ncname (tmp.data (), size))
             str_.resize (size);
           else
-            schema_error (schema_error::invalid_ncname_value);
+            _schema_error (schema_error::invalid_ncname_value);
         }
 
         std::string ncname_pimpl::
