@@ -1,6 +1,6 @@
 // file      : xsde/cxx/parser/validating/string.cxx
 // author    : Boris Kolpackov <boris@codesynthesis.com>
-// copyright : Copyright (c) 2005-2007 Code Synthesis Tools CC
+// copyright : Copyright (c) 2005-2008 Code Synthesis Tools CC
 // license   : GNU GPL v2 + exceptions; see accompanying LICENSE file
 
 #include <xsde/cxx/config.hxx>
@@ -22,7 +22,7 @@ namespace xsde
           str_.assign ("", 0);
 #else
           if (str_.assign ("", 0))
-            sys_error (sys_error::no_memory);
+            _sys_error (sys_error::no_memory);
 #endif
         }
 
@@ -33,7 +33,7 @@ namespace xsde
           str_.append (s.data (), s.size ());
 #else
           if (str_.append (s.data (), s.size ()))
-            sys_error (sys_error::no_memory);
+            _sys_error (sys_error::no_memory);
 #endif
         }
 
